@@ -1,4 +1,3 @@
-import itertools
 import json
 import sqlite3
 from datetime import datetime
@@ -12,9 +11,9 @@ def txtBlock(s: any) -> str:
     else:
         return ""
 
-def txtJson(s: any)->str:
-    return json.dumps(s)
 
+def txtJson(s: any) -> str:
+    return json.dumps(s)
 
 
 def commaInt(x: str) -> int:
@@ -84,9 +83,11 @@ class SQLX:
                            wroteerr text NOT NULL,
                            time INTEGER NOT NULL
                    );''')
+
     """
     host name as return
     """
+
     def datainput(self, j: dict, ts: int) -> str:
         host = txtBlock(j['identity'])
         if len(j['jobls']) > 0:
@@ -99,6 +100,7 @@ class SQLX:
                     content_find = f"""
 
                     SELECT COUNT(*) FROM plotv2 WHERE plotid='{plot_id}';
+
                     """
 
                     (n,) = self.cur.execute(content_find).fetchone()
@@ -145,7 +147,6 @@ class SQLX:
 
         try:
 
-            print(j)
             content_insert = f"""
             INSERT INTO nodeInfo (
 
@@ -157,7 +158,7 @@ class SQLX:
 
                 version,chia_ver,
 
-                timen
+                net_fds,timen
 
             ) VALUES(
 
@@ -184,6 +185,7 @@ class SQLX:
                 
                 '{txtBlock(j['version'])}',
                 '{txtBlock(j['chia_ver'])}',
+                0,
                 {int(datetime.now().timestamp())}
             )
             """
@@ -197,7 +199,7 @@ class SQLX:
 
     def getNodes(self) -> list:
         block = """
-        SELECT * FROM nodeInfo GROUP BY host ORDER BY timen DESC
+        SELECT * FROM nodeInfo ORDER BY timen DESC GROUP BY host
         """
 
         listd = self.cur.execute(block).fetchall()
@@ -206,6 +208,4 @@ class SQLX:
             orders = list(orders_iter)
             total_qty = sum(order[2] for order in orders)"""
 
-
-
         return listd
